@@ -129,7 +129,7 @@ class RedisCustomer(object):
                 message = self._redis_quenen.get()
                 if message:
                     if self.qps != 0:
-                        time.sleep((1 / self.qps)*self.process_num)
+                        time.sleep((1 / self.qps) * self.process_num)
                     if self.is_support_mutil_param:
                         message = json.loads(message)
                         if type(message) != dict:
@@ -274,36 +274,34 @@ if __name__ == '__main__':
     redis_port = 6379
     redis_db = 8
 
-    quenen_name = 'test1'
-    # 初始化发布队列 fliter_rep=True任务自动去重
-    redis_pub = RedisPublish(queue_name=quenen_name, fliter_rep=False, max_push_size=50)
-
-    result = [str(i) for i in range(1, 101)]
+    for zz in range(1, 501):
+        # 发布字符串任务 queue_name发布队列名称 fliter_rep=True任务自动去重(默认False)
+        RedisPublish(queue_name='test1', fliter_rep=False).publish_redispy_str(str(zz))
 
 
     def print_msg_str(msg):
         print(f"msg_str:{msg}")
 
 
-    # for zz in result:
-    #     redis_pub.publish_redispy_str(zz)  # 写入字符串任务
-    #
-    # # 多线程消费字符串任务
-    # redis_customer = RedisCustomer(quenen_name, consuming_function=print_msg_str, process_num=2, threads_num=100,
-    #                                max_retry_times=5, qps=10)
-    # redis_customer.start_consuming_message()
+    # 消费字符串任务 queue_name消费队列名称 max_retry_times错误最大重试次数
+    RedisCustomer(queue_name='test1', consuming_function=print_msg_str, process_num=2, threads_num=100,
+                  max_retry_times=5).start_consuming_message()
 
-    for zz in result:
-        redis_pub.publish_redispy(c=zz, b=zz, a=zz)  # 写入字典任务 {"c":zz,"b":zz,"a":zz}
+    # #### 2.发布消费多参数类型任务
+    for zz in range(1, 501):
+        # 写入字典任务 {"c":zz,"b":zz,"a":zz}
+        RedisPublish(queue_name='test2').publish_redispy(c=str(zz), b=str(zz), a=str(zz))
 
 
-    # redis_pub.publish_redispy_list(result)  # 批量提交任务1
-
     def print_msg_dict(a, b, c):
         print(f"msg_dict:{a},{b},{c}")
 
 
-    # 多线程消费字典任务
-    redis_customer = RedisCustomer(quenen_name, consuming_function=print_msg_dict, process_num=5, threads_num=100,
-                                   max_retry_times=5, is_support_mutil_param=True, qps=50)
-    redis_customer.start_consuming_message()
+    # 消费多参数类型任务 queue_name消费队列名称 is_support_mutil_param=True消费函数支持多参数(默认False) qps每秒消费任务数
+    RedisCustomer(queue_name='test2', consuming_function=print_msg_dict, process_num=2, threads_num=100,
+                  max_retry_times=5, is_support_mutil_param=True, qps=50).start_consuming_message()
+
+    # #### 3.批量提交任务
+    result = [str(i) for i in range(1, 501)]
+    # 批量提交任务 queue_name提交任务队列名称 max_push_size每次批量提交记录数(默认值50)
+    RedisPublish(queue_name='test3', max_push_size=100).publish_redispy_list(result)
